@@ -1,3 +1,9 @@
+/*
+ * SPDX-FileCopyrightText: 2014-2015 David Rosca <nowrep@gmail.com>
+ *
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+ */
+
 #ifndef ADAPTERTEST_H
 #define ADAPTERTEST_H
 
@@ -15,7 +21,7 @@ class AdapterTest : public QObject
     Q_OBJECT
 
 public:
-    explicit AdapterTest(bool fakeBluezRun = false);
+    explicit AdapterTest();
 
 private Q_SLOTS:
     void initTestCase();
@@ -43,7 +49,6 @@ private:
 
     BluezQt::Manager *m_manager;
     QList<AdapterUnit> m_units;
-    bool m_fakeBluezRun;
 };
 
 #endif // ADAPTERTEST_H
